@@ -7,7 +7,7 @@ use warnings;
 use autodie;
 use namespace::autoclean;
 
-our $VERSION = '1.13';
+our $VERSION = '1.14';
 
 use Devel::PPPort 3.42;
 use Dist::Zilla 6.0;
@@ -581,6 +581,7 @@ sub _prompt_if_stale_plugin {
                 check_authordeps  => 1,
                 skip              => [
                     qw(
+                        Dist::Zilla::Plugin::DROLSKY::BundleAuthordep
                         Dist::Zilla::Plugin::DROLSKY::Contributors
                         Dist::Zilla::Plugin::DROLSKY::Git::CheckFor::CorrectBranch
                         Dist::Zilla::Plugin::DROLSKY::License
@@ -667,10 +668,9 @@ sub _default_stopwords {
 sub _extra_test_plugins {
     my $self = shift;
 
-    return (
+    my @plugins = (
         qw(
             DROLSKY::RunExtraTests
-            DROLSKY::Test::Precious
             MojibakeTests
             Test::CleanNamespaces
             Test::CPAN::Changes
@@ -684,6 +684,11 @@ sub _extra_test_plugins {
         [ 'Test::ReportPrereqs' => { verify_prereqs => 1 } ],
         [ 'Test::Version'       => { is_strict      => 1 } ],
     );
+
+    push @plugins,
+        -f 'tidyall.ini' ? 'Test::TidyAll' : 'DROLSKY::Test::Precious';
+
+    return @plugins;
 }
 
 sub _contributors_plugins {
@@ -862,7 +867,7 @@ Dist::Zilla::PluginBundle::DROLSKY - DROLSKY's plugin bundle
 
 =head1 VERSION
 
-version 1.13
+version 1.14
 
 =head1 SYNOPSIS
 
@@ -1008,6 +1013,7 @@ This is more or less equivalent to the following F<dist.ini>:
     check_all_plugins = 1
     check_all_prereqs = 1
     check_authordeps  = 1
+    skip = Dist::Zilla::Plugin::DROLSKY::BundleAuthordep
     skip = Dist::Zilla::Plugin::DROLSKY::Contributors
     skip = Dist::Zilla::Plugin::DROLSKY::Git::CheckFor::CorrectBranch
     skip = Dist::Zilla::Plugin::DROLSKY::License
@@ -1016,6 +1022,7 @@ This is more or less equivalent to the following F<dist.ini>:
     skip = Dist::Zilla::Plugin::DROLSKY::Precious
     skip = Dist::Zilla::Plugin::DROLSKY::Role::CoreCounter
     skip = Dist::Zilla::Plugin::DROLSKY::RunExtraTests
+    skip = Dist::Zilla::Plugin::DROLSKY::Test::Precious
     skip = Dist::Zilla::Plugin::DROLSKY::WeaverConfig
     skip = Pod::Weaver::PluginBundle::DROLSKY
 
